@@ -31,7 +31,19 @@ func (Pipe) Run(ctx *context.Context) (err error) {
 	filename := name + "." + ctx.Config.Source.Format
 	path := filepath.Join(ctx.Config.Dist, filename)
 	log.WithField("file", filename).Info("creating source archive")
-	out, err := git.Clean(git.Run("archive", "-o", path, ctx.Git.FullCommit))
+	args := []string{
+		"archive",
+		"-o", path,
+	}
+	if ctx.Config.Source.PrefixTemplate != "" {
+		prefix, err := tmpl.New(ctx).Apply(ctx.Config.Source.PrefixTemplate)
+		if err != nil {
+			return err
+		}
+		args = append(args, "--prefix", prefix)
+	}
+	args = append(args, ctx.Git.FullCommit)
+	out, err := git.Clean(git.Run(args...))
 	log.Debug(out)
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Type: artifact.UploadableSourceArchive,
