@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"io"
 	"os/exec"
+	"strings"
 
 	"github.com/apex/log"
 
@@ -14,7 +15,7 @@ import (
 )
 
 // Run a shell command with given arguments and envs
-func Run(ctx *context.Context, dir string, command, env []string) error {
+func Run(ctx *context.Context, dir string, command, env []string, output bool) error {
 	fields := log.Fields{
 		"cmd": command,
 		"env": env,
@@ -27,8 +28,8 @@ func Run(ctx *context.Context, dir string, command, env []string) error {
 	var b bytes.Buffer
 	w := gio.Safe(&b)
 
-	cmd.Stderr = io.MultiWriter(logext.NewWriter(fields, logext.Error), w)
-	cmd.Stdout = io.MultiWriter(logext.NewWriter(fields, logext.Info), w)
+	cmd.Stderr = io.MultiWriter(logext.NewConditionalWriter(fields, logext.Error, output), w)
+	cmd.Stdout = io.MultiWriter(logext.NewConditionalWriter(fields, logext.Info, output), w)
 
 	if dir != "" {
 		cmd.Dir = dir
@@ -37,7 +38,7 @@ func Run(ctx *context.Context, dir string, command, env []string) error {
 	log.WithFields(fields).Debug("running")
 	if err := cmd.Run(); err != nil {
 		log.WithFields(fields).WithError(err).Debug("failed")
-		return fmt.Errorf("%q: %w", b.String(), err)
+		return fmt.Errorf("failed to run '%s': %w", strings.Join(command, " "), err)
 	}
 
 	return nil
